@@ -1,23 +1,51 @@
+import os
 import unittest
 from unittest import mock
 
 import skelebot as sb
 
+DASH_TEMPLATE = {
+    "dirs": ["src/assets/"],
+    "files": [
+        {
+            "name": "src/app.py",
+            "template": "files/app_py"
+        },{
+            "name": "src/server.py",
+            "template": "files/server_py"
+        },{
+            "name": "src/config.py",
+            "template": "files/config_py"
+        },{
+            "name": "src/assets/style.css",
+            "template": "files/style_css"
+        }
+    ],
+    "config": {
+        "language": "Python",
+        "dependencies": ["dash~=2.0"],
+        "ports": ["5000:5000"],
+        "primaryJob": "run",
+        "jobs": {
+            "name": "run",
+            "source": "src/app.py",
+            "help": "Start the Dashboard"
+        }
+    }
+}
+
 class TestScaffolder(unittest.TestCase):
 
     @mock.patch('os.path.expanduser')
-    @mock.patch('os.path.exists')
     @mock.patch('os.getcwd')
     @mock.patch('skelebot.systems.scaffolding.scaffolder.ComponentFactory')
     @mock.patch('skelebot.systems.scaffolding.scaffolder.promptUser')
-    def test_execute_scaffold_abort(self, mock_prompt, mock_cFactory, mock_getcwd, mock_exists,
-                                    mock_expanduser):
+    def test_execute_scaffold_abort(self, mock_prompt, mock_cFactory, mock_getcwd, mock_expanduser):
         mock_expanduser.return_value = "test/plugins"
-        mock_exists.return_value = False
-        mock_prompt.side_effect = ["test", "test proj", "sean", "email", "Python", False]
-
+        mock_prompt.side_effect = ["test", "test proj", "sean", "email", "Python", "Default", False]
         try:
-            sb.systems.scaffolding.scaffolder.scaffold(False)
+            scaffolder = sb.systems.scaffolding.scaffolder.Scaffolder(existing=False)
+            scaffolder.scaffold()
             self.fail("Exception Expected")
         except Exception as exc:
             self.assertEqual(str(exc), "Aborting Scaffolding Process")
@@ -26,50 +54,53 @@ class TestScaffolder(unittest.TestCase):
             mock_prompt.assert_any_call("Enter a PROJECT DESCRIPTION")
             mock_prompt.assert_any_call("Enter a MAINTAINER NAME")
             mock_prompt.assert_any_call("Enter a CONTACT EMAIL")
-            mock_prompt.assert_any_call("Enter a LANGUAGE", options=["Python", "R","R+Python"])
+            mock_prompt.assert_any_call("Select a LANGUAGE", options=["Python", "R", "R+Python"])
+            mock_prompt.assert_any_call("Select a TEMPLATE", options=["Default", "Dash"])
             mock_prompt.assert_any_call("Confirm Skelebot Setup", boolean=True)
 
     @mock.patch('os.path.expanduser')
-    @mock.patch('os.path.exists')
     @mock.patch('os.getcwd')
     @mock.patch('os.makedirs')
     #@mock.patch('skelebot.systems.scaffolding.scaffolder.ComponentFactory')
     @mock.patch('skelebot.systems.scaffolding.scaffolder.yaml')
     @mock.patch('skelebot.systems.scaffolding.scaffolder.promptUser')
     def test_execute_scaffold_existing_init(self, mock_prompt, mock_yaml, #mock_cFactory,
-                                            mock_makedirs, mock_getcwd, mock_exists,
-                                            mock_expanduser):
+                                            mock_makedirs, mock_getcwd, mock_expanduser):
         mock_expanduser.return_value = "test/plugins"
-        mock_exists.return_value = False
-        mock_prompt.side_effect = ["test", "test proj", "sean", "email", "Python", True]
+        mock_prompt.side_effect = ["test", "test proj", "sean", "email", "Python", "Dash", True]
 
-        sb.systems.scaffolding.scaffolder.scaffold(True)
+        scaffolder = sb.systems.scaffolding.scaffolder.Scaffolder(existing=True)
+        scaffolder.scaffold()
 
         mock_prompt.assert_any_call("Enter a PROJECT NAME")
         mock_prompt.assert_any_call("Enter a PROJECT DESCRIPTION")
         mock_prompt.assert_any_call("Enter a MAINTAINER NAME")
         mock_prompt.assert_any_call("Enter a CONTACT EMAIL")
-        mock_prompt.assert_any_call("Enter a LANGUAGE", options=["Python", "R","R+Python"])
+        mock_prompt.assert_any_call("Select a LANGUAGE", options=["Python", "R", "R+Python"])
+        mock_prompt.assert_any_call("Select a TEMPLATE", options=["Default", "Dash"])
         mock_prompt.assert_any_call("Confirm Skelebot Setup", boolean=True)
 
         mock_yaml.saveConfig.assert_called_once()
 
     @mock.patch('os.path.expanduser')
-    @mock.patch('os.path.exists')
     @mock.patch('os.getcwd')
     @mock.patch('os.makedirs')
+    @mock.patch('skelebot.systems.scaffolding.scaffolder.open')
     @mock.patch('skelebot.systems.scaffolding.scaffolder.Config')
     @mock.patch('skelebot.systems.scaffolding.scaffolder.ComponentFactory')
     @mock.patch('skelebot.systems.scaffolding.scaffolder.dockerfile')
     @mock.patch('skelebot.systems.scaffolding.scaffolder.dockerignore')
+    @mock.patch('skelebot.systems.scaffolding.scaffolder.pyyaml')
     @mock.patch('skelebot.systems.scaffolding.scaffolder.readme')
     @mock.patch('skelebot.systems.scaffolding.scaffolder.yaml')
     @mock.patch('skelebot.systems.scaffolding.scaffolder.promptUser')
-    def test_execute_scaffold(self, mock_prompt, mock_yaml, mock_readme, mock_dignore,
-                              mock_dockerfile, mock_cFactory, mock_config, mock_makedirs,
-                              mock_getcwd, mock_exists, mock_expanduser):
+    def test_execute_scaffold_dash(self, mock_prompt, mock_yaml, mock_readme, mock_pyyaml,
+                              mock_dignore, mock_dockerfile, mock_cFactory, mock_config, mock_open,
+                              mock_makedirs, mock_getcwd, mock_expanduser):
         mock_expanduser.return_value = "test/plugins"
-        mock_prompt.side_effect = ["test", "test proj", "sean", "email", "Python", True]
+        mock_prompt.side_effect = ["test", "test proj", "sean", "email", "Python", "Dash", True]
+
+        mock_pyyaml.load.return_value = DASH_TEMPLATE
 
         # Set up mock components with scaffolding
         mock_single_comp = mock.MagicMock()
@@ -81,25 +112,29 @@ class TestScaffolder(unittest.TestCase):
             mock_single_comp, mock_list_comp
         ]
 
-        sb.systems.scaffolding.scaffolder.scaffold()
+        scaffolder = sb.systems.scaffolding.scaffolder.Scaffolder(existing=False)
+        scaffolder.scaffold()
 
         mock_prompt.assert_any_call("Enter a PROJECT NAME")
         mock_prompt.assert_any_call("Enter a PROJECT DESCRIPTION")
         mock_prompt.assert_any_call("Enter a MAINTAINER NAME")
         mock_prompt.assert_any_call("Enter a CONTACT EMAIL")
-        mock_prompt.assert_any_call("Enter a LANGUAGE", options=["Python", "R","R+Python"])
+        mock_prompt.assert_any_call("Select a LANGUAGE", options=["Python", "R", "R+Python"])
+        mock_prompt.assert_any_call("Select a TEMPLATE", options=["Default", "Dash"])
         mock_prompt.assert_any_call("Confirm Skelebot Setup", boolean=True)
 
-        mock_config.assert_called_once()
-        self.assertEqual(['foo', 'bar', 'baz'], mock_config.call_args[1]['components'])
+        mock_config.load.assert_called_once()
 
-        mock_makedirs.assert_any_call("config/", exist_ok=True)
-        mock_makedirs.assert_any_call("data/", exist_ok=True)
-        mock_makedirs.assert_any_call("models/", exist_ok=True)
-        mock_makedirs.assert_any_call("notebooks/", exist_ok=True)
-        mock_makedirs.assert_any_call("output/", exist_ok=True)
-        mock_makedirs.assert_any_call("queries/", exist_ok=True)
-        mock_makedirs.assert_any_call("src/jobs/", exist_ok=True)
+        mock_makedirs.assert_any_call("src/assets/", exist_ok=True)
+        dirname = os.path.dirname(os.path.dirname(__file__))
+        mock_open.assert_any_call(os.path.join(dirname, "skelebot/systems/scaffolding/templates/python_dash/files/app_py"), "r")
+        mock_open.assert_any_call("src/app.py", "w")
+        mock_open.assert_any_call(os.path.join(dirname, "skelebot/systems/scaffolding/templates/python_dash/files/server_py"), "r")
+        mock_open.assert_any_call("src/server.py", "w")
+        mock_open.assert_any_call(os.path.join(dirname, "skelebot/systems/scaffolding/templates/python_dash/files/config_py"), "r")
+        mock_open.assert_any_call("src/config.py", "w")
+        mock_open.assert_any_call(os.path.join(dirname, "skelebot/systems/scaffolding/templates/python_dash/files/style_css"), "r")
+        mock_open.assert_any_call("src/assets/style.css", "w")
 
         mock_dockerfile.buildDockerfile.assert_called_once()
         mock_dignore.buildDockerignore.assert_called_once()
@@ -124,6 +159,11 @@ class TestScaffolder(unittest.TestCase):
         mock_input.assert_called_with("Select an Algorithm [glm, rf, lgbm]: ")
         self.assertEqual(msg, "rf")
 
+    def test_scaffold_prompt_option(self):
+        msg = sb.systems.scaffolding.prompt.promptUser("Select an Algorithm", options=["glm"])
+
+        self.assertEqual(msg, "glm")
+
     @mock.patch('skelebot.systems.scaffolding.prompt.input')
     def test_scaffold_prompt_boolean(self, mock_input):
         mock_input.return_value = "Y"
